@@ -1,40 +1,32 @@
 /****************************************************************************
 **
-** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
+** Copyright (C) 2014 Digia Plc and/or its subsidiary(-ies).
 ** Contact: http://www.qt-project.org/legal
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL$
+** $QT_BEGIN_LICENSE:LGPL21$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Digia.  For licensing terms and
-** conditions see http://qt.digia.com/licensing.  For further information
+** a written agreement between you and Digia. For licensing terms and
+** conditions see http://qt.digia.com/licensing. For further information
 ** use the contact form at http://qt.digia.com/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** General Public License version 2.1 or version 3 as published by the Free
+** Software Foundation and appearing in the file LICENSE.LGPLv21 and
+** LICENSE.LGPLv3 included in the packaging of this file. Please review the
+** following information to ensure the GNU Lesser General Public License
+** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
+** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
 ** In addition, as a special exception, Digia gives you certain additional
-** rights.  These rights are described in the Digia Qt LGPL Exception
+** rights. These rights are described in the Digia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
-**
-**
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -510,7 +502,7 @@ bool KeymapParser::generateHeader(QFile *f)
     ts << "#ifndef QEVDEVKEYBOARDHANDLER_DEFAULTMAP_H" << endl;
     ts << "#define QEVDEVKEYBOARDHANDLER_DEFAULTMAP_H" << endl << endl;
 
-    ts << "const QEvdevKeyboardMap::Mapping QWSKbPrivate::s_keymap_default[] = {" << endl;
+    ts << "const QEvdevKeyboardMap::Mapping QEvdevKeyboardHandler::s_keymap_default[] = {" << endl;
 
     for (int i = 0; i < m_keymap.size(); ++i) {
         const QEvdevKeyboardMap::Mapping &m = m_keymap.at(i);
@@ -521,7 +513,7 @@ bool KeymapParser::generateHeader(QFile *f)
 
     ts << "};" << endl << endl;
 
-    ts << "const QEvdevKeyboardMap::Composing QWSKbPrivate::s_keycompose_default[] = {" << endl;
+    ts << "const QEvdevKeyboardMap::Composing QEvdevKeyboardHandler::s_keycompose_default[] = {" << endl;
 
     for (int i = 0; i < m_keycompose.size(); ++i) {
         const QEvdevKeyboardMap::Composing &c = m_keycompose.at(i);
@@ -682,7 +674,7 @@ bool KeymapParser::parseKmap(QFile *f)
                 parseWarning("codec doesn't habe exactly one argument");
         }
         else if (tokens[0] == "strings") {
-            // simply ignore those - they have no meaning for QWS
+            // simply ignore those - they have no meaning for us
         }
         else if (tokens[0] == "compose") {
             if (tokens.count() == 5 && tokens[3] == "to") {
@@ -883,8 +875,6 @@ bool KeymapParser::parseSymbol(const QByteArray &str, const QTextCodec * /*codec
     if (sym == "VoidSymbol" || sym == "nul")
         return true;
 
-    bool try_to_find_qtcode = false;
-
     if (sym[0] >= '0' && sym[0] <= '9') {  // kernel internal action number
         return false;
     } else if (sym.length() == 6 && sym[1] == '+' && (sym[0] == 'U' || sym[0] == 'u')) { // unicode
@@ -892,7 +882,6 @@ bool KeymapParser::parseSymbol(const QByteArray &str, const QTextCodec * /*codec
         unicode = sym.mid(2).toUInt(&ok, 16);
         if (!ok)
             return false;
-        try_to_find_qtcode = true;
     } else { // symbolic
         for (int i = 0; i < symbol_synonyms_size; ++i) {
             if (sym == symbol_synonyms[i].from) {
