@@ -5,36 +5,28 @@
 **
 ** This file is part of the tools applications of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL$
+** $QT_BEGIN_LICENSE:LGPL21$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Digia.  For licensing terms and
-** conditions see http://qt.digia.com/licensing.  For further information
+** a written agreement between you and Digia. For licensing terms and
+** conditions see http://qt.digia.com/licensing. For further information
 ** use the contact form at http://qt.digia.com/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** General Public License version 2.1 or version 3 as published by the Free
+** Software Foundation and appearing in the file LICENSE.LGPLv21 and
+** LICENSE.LGPLv3 included in the packaging of this file. Please review the
+** following information to ensure the GNU Lesser General Public License
+** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
+** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
 ** In addition, as a special exception, Digia gives you certain additional
-** rights.  These rights are described in the Digia Qt LGPL Exception
+** rights. These rights are described in the Digia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
-**
-**
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -64,10 +56,13 @@
 #include <QtCore/QTextStream>
 #include <QtCore/QStandardPaths>
 #include <QtCore/QDir>
+#include <QtCore/QFileSelector>
 
+#include <private/qsimd_p.h>
 #include <private/qguiapplication_p.h>
 #include <qpa/qplatformintegration.h>
 #include <qpa/qplatformtheme.h>
+#include <qpa/qplatformnativeinterface.h>
 
 #include <algorithm>
 
@@ -195,6 +190,10 @@ static void dumpStandardLocation(QTextStream &str, QStandardPaths::StandardLocat
         str << " *" << QDir::toNativeSeparators(writableDirectory) << '*';
 }
 
+#define DUMP_CPU_FEATURE(feature, name)                 \
+    if (qCpuHasFeature(feature))                        \
+        str << " " name;
+
 #define DUMP_STANDARDPATH(str, location) \
     str << "  " << #location << ": "; \
     dumpStandardLocation(str, QStandardPaths::location); \
@@ -211,14 +210,22 @@ QString qtDiag(unsigned flags)
 
     const QPlatformIntegration *platformIntegration = QGuiApplicationPrivate::platformIntegration();
     str << QLibraryInfo::build() << " on \"" << QGuiApplication::platformName() << "\" "
-              << (QSysInfo::ByteOrder == QSysInfo::LittleEndian ? "little endian" : "big endian") << '/'
-              << '\n';
+              << '\n'
+        << "OS: " << QSysInfo::prettyProductName()
+              << " [" << QSysInfo::kernelType() << " version " << QSysInfo::kernelVersion() << "]\n";
 
-#if defined(Q_OS_WIN)
-    str << hex << "Windows version: 0x" << QSysInfo::windowsVersion() << dec << '\n';
-#elif defined(Q_OS_MAC)
-    str << hex << "Mac OS version: 0x" << QSysInfo::macVersion() << dec << '\n';
-#endif
+    str << "\nArchitecture: " << QSysInfo::currentCpuArchitecture() << "; features:";
+    DUMP_CPU_FEATURE(SSE2, "SSE2");
+    DUMP_CPU_FEATURE(SSE3, "SSE3");
+    DUMP_CPU_FEATURE(SSSE3, "SSSE3");
+    DUMP_CPU_FEATURE(SSE4_1, "SSE4.1");
+    DUMP_CPU_FEATURE(SSE4_2, "SSE4.2");
+    DUMP_CPU_FEATURE(AVX, "AVX");
+    DUMP_CPU_FEATURE(AVX2, "AVX2");
+    DUMP_CPU_FEATURE(RTM, "RTM");
+    DUMP_CPU_FEATURE(HLE, "HLE");
+    DUMP_CPU_FEATURE(ARM_NEON, "Neon");
+    str << '\n';
 
     str << "\nLibrary info:\n";
     DUMP_LIBRARYPATH(str, PrefixPath)
@@ -255,12 +262,16 @@ QString qtDiag(unsigned flags)
     DUMP_STANDARDPATH(str, GenericCacheLocation)
     DUMP_STANDARDPATH(str, GenericConfigLocation)
 
-    str << "\nNetwork:\n  ";
+    str << "\nFile selectors (increasing order of precedence):\n ";
+    foreach (const QString &s, QFileSelector().allSelectors())
+        str << ' ' << s;
+
+    str << "\n\nNetwork:\n  ";
 #ifdef NETWORK_DIAG
 #  ifndef QT_NO_SSL
     if (QSslSocket::supportsSsl()) {
-        str << "Using \"" << QSslSocket::sslLibraryVersionString() << "\", version: "
-            << QSslSocket::sslLibraryVersionNumber();
+        str << "Using \"" << QSslSocket::sslLibraryVersionString() << "\", version: 0x"
+            << hex << QSslSocket::sslLibraryVersionNumber() << dec;
     } else {
         str << "\nSSL is not supported.";
     }
@@ -366,6 +377,14 @@ QString qtDiag(unsigned flags)
 #else
     Q_UNUSED(flags)
 #endif // !QT_NO_OPENGL
+
+    // On Windows, this will provide addition GPU info similar to the output of dxdiag.
+    const QVariant gpuInfoV = QGuiApplication::platformNativeInterface()->property("gpu");
+    if (gpuInfoV.type() == QVariant::Map) {
+        const QString description = gpuInfoV.toMap().value(QStringLiteral("printable")).toString();
+        if (!description.isEmpty())
+            str << "\nGPU:\n" << description;
+    }
     return result;
 }
 
